package com.tofly.watermeter.custom.mapper;

import com.tofly.watermeter.custom.dto.*;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

@Mapper
public interface DmaCodeMapper {

  boolean deleteData(@Param("tableName") String tableName);

  boolean insertAreaCode(@Param("dto") List<AreaCodeDto> dto);
  boolean insertAreaCodeQfcb(@Param("dto") List<AreaCodeDto> dto);

  boolean insertBookCode(@Param("dto") List<BookCodeDto> dto);

  boolean insertVendorCode(@Param("dto") List<VendorCodeDto> dto);

  boolean insertTypeCode(@Param("dto") List<TypeCodeDto> dto);

  boolean insertReadBookCode(@Param("dto") List<ReadBookDto> dto);
}
